import 'package:flutter/material.dart';
import 'package:image_picker/image_picker.dart';
import 'package:file_picker/file_picker.dart';
import 'package:geolocator/geolocator.dart';
import 'package:geocoding/geocoding.dart';
import 'package:flutter_map/flutter_map.dart';
import 'package:latlong2/latlong.dart';
import 'package:Monitoring/controllers/report_controller.dart';
import 'package:Monitoring/models/report_model.dart';
import 'dart:io';

class EditLaporanKegiatan extends StatefulWidget {
  const EditLaporanKegiatan({
    super.key,
    required this.taskId,
    // required this.report,
  });

  final String taskId;
  // final ReportModel report;

  @override
  _EditLaporanKegiatanState createState() => _EditLaporanKegiatanState();
}

class _EditLaporanKegiatanState extends State<EditLaporanKegiatan> {
  final ImagePicker _picker = ImagePicker();
  XFile? _image;
  String? _imagePath;
  String? _documentPath;
  String _currentLocation = 'Lokasi belum dideteksi';
  String _address = 'Alamat belum tersedia';
  String _selectedStatus = 'Diterima';
  bool _isLoading = true;
  bool _isSaving = false;
  final TextEditingController _deskripsiController = TextEditingController();
  final ReportController _reportController = ReportController();

  LatLng _currentPosition = LatLng(-7.6195984, 110.95142615);
  final MapController _mapController = MapController();

  @override
  void initState() {
    super.initState();
    // _getCurrentLocation();
    // _reportController.getReport(widget.taskId);
    _reportController.getReport2(widget.taskId).then((_) {
      if (mounted) {
        setState(() {
          _deskripsiController.text =
              _reportController.report.value.first.description!;
          _currentPosition.longitude =
              _reportController.report.value.first.longitude!;
          _currentPosition.latitude =
              _reportController.report.value.first.latitude!;
          _selectedStatus = _reportController.report.value.first.status!;
          _isLoading = false;
        });
      }
    });
  }

  @override
  void dispose() {
    _deskripsiController.dispose();
    super.dispose();
  }

  Future<void> _getCurrentLocation() async {
    bool serviceEnabled;
    LocationPermission permission;

    serviceEnabled = await Geolocator.isLocationServiceEnabled();
    if (!serviceEnabled) {
      setState(() {
        _currentLocation = 'Layanan lokasi dinonaktifkan.';
      });
      return;
    }

    permission = await Geolocator.checkPermission();
    if (permission == LocationPermission.denied) {
      permission = await Geolocator.requestPermission();
      if (permission == LocationPermission.denied) {
        setState(() {
          _currentLocation = 'Izin lokasi ditolak';
        });
        return;
      }
    }

    if (permission == LocationPermission.deniedForever) {
      setState(() {
        _currentLocation = 'Izin lokasi ditolak secara permanen.';
      });
      return;
    }

    Position position = await Geolocator.getCurrentPosition(
        desiredAccuracy: LocationAccuracy.high);

    try {
      List<Placemark> placemarks = await placemarkFromCoordinates(
        position.latitude,
        position.longitude,
      );

      Placemark place = placemarks[0];
      String formattedAddress =
          '${place.street}, ${place.locality}, ${place.subAdministrativeArea}, ${place.postalCode}, ${place.country}';

      setState(() {
        _currentPosition = LatLng(position.latitude, position.longitude);
        _isLoading = false;
        _currentLocation = '${position.latitude}, ${position.longitude}';
        _address = formattedAddress;

        _mapController.move(_currentPosition, 13.0);
      });
    } catch (e) {
      setState(() {
        _address = 'Tidak dapat menemukan alamat';
      });
    }
  }

  Future<void> _pickImage() async {
    final pickedFile = await _picker.pickImage(source: ImageSource.camera);
    setState(() {
      _image = pickedFile;
      _imagePath = _image!.path;
    });
  }

  Future<void> _pickDocument() async {
    final result = await FilePicker.platform.pickFiles(
      allowMultiple: false,
      type: FileType.any,
    );

    if (result != null) {
      setState(() {
        _documentPath = result.files.single.path;
      });
    }
  }

  Future<void> _saveLaporan() async {
    if (_isSaving) return;

    setState(() {
      _isSaving = true;
    });

    try {
      // Show loading dialog
      showDialog(
        context: context,
        barrierDismissible: false,
        builder: (BuildContext context) {
          return Center(
            child: Card(
              child: Container(
                padding: EdgeInsets.all(16.0),
                child: Column(
                  mainAxisSize: MainAxisSize.min,
                  children: [
                    CircularProgressIndicator(),
                    SizedBox(height: 16),
                    Text('Menyimpan laporan...'),
                  ],
                ),
              ),
            ),
          );
        },
      );

      // Add your save logic here
      // For example:
      // await saveToAPI({
      //   'taskId': widget.taskId,
      //   'status': _selectedStatus,
      //   'location': _currentLocation,
      //   'address': _address,
      //   'notes': _deskripsiController.text,
      //   'image': _image?.path,
      //   'document': _documentPath,
      // });

      // Simulate network delay
      await Future.delayed(Duration(seconds: 2));

      // Close loading dialog
      Navigator.of(context).pop();

      // Show success message
      ScaffoldMessenger.of(context).showSnackBar(
        SnackBar(
          content: Text('Laporan berhasil disimpan'),
          backgroundColor: Colors.green,
        ),
      );

      // Return to previous screen
      Navigator.of(context).pop();
    } catch (e) {
      // Close loading dialog
      Navigator.of(context).pop();

      // Show error message
      ScaffoldMessenger.of(context).showSnackBar(
        SnackBar(
          content: Text('Gagal menyimpan laporan: ${e.toString()}'),
          backgroundColor: Colors.red,
        ),
      );
    } finally {
      setState(() {
        _isSaving = false;
      });
    }
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text(
          'Edit Laporan Kegiatan',
          style: TextStyle(color: Colors.black),
        ),
        centerTitle: true,
        backgroundColor: Colors.blue[100],
        leading: IconButton(
          icon: Icon(Icons.arrow_back, color: Colors.black),
          onPressed: () {
            Navigator.pop(context);
          },
        ),
      ),
      body: Stack(
        children: <Widget>[
          _isLoading
              ? Center(child: CircularProgressIndicator())
              : FlutterMap(
                  mapController: _mapController,
                  options: MapOptions(
                    // MapController:_mapController;
                    center: _currentPosition,
                    zoom: 13.0,
                  ),
                  children: [
                    TileLayer(
                      urlTemplate:
                          "https://{s}.tile.openstreetmap.org/{z}/{x}/{y}.png",
                      subdomains: ['a', 'b', 'c'],
                    ),
                    MarkerLayer(
                      markers: [
                        Marker(
                          point: _currentPosition,
                          builder: (ctx) => Icon(
                            Icons.location_pin,
                            color: Colors.red,
                            size: 40,
                          ),
                          width: 80.0,
                          height: 80.0,
                        ),
                      ],
                    ),
                  ],
                ),
          DraggableScrollableSheet(
            initialChildSize: 0.3,
            minChildSize: 0.1,
            maxChildSize: 0.9,
            builder: (BuildContext context, ScrollController scrollController) {
              return Container(
                decoration: BoxDecoration(
                  color: Colors.white,
                  borderRadius: BorderRadius.only(
                    topLeft: Radius.circular(20),
                    topRight: Radius.circular(20),
                  ),
                  boxShadow: [
                    BoxShadow(
                      color: Colors.black.withOpacity(0.1),
                      blurRadius: 10,
                      spreadRadius: 5,
                    ),
                  ],
                ),
                child: Column(
                  children: [
                    Container(
                      width: 40,
                      height: 5,
                      margin: EdgeInsets.symmetric(vertical: 8),
                      decoration: BoxDecoration(
                        color: Colors.grey[300],
                        borderRadius: BorderRadius.circular(2.5),
                      ),
                    ),
                    Expanded(
                      child: ListView(
                        controller: scrollController,
                        padding: EdgeInsets.all(16),
                        children: <Widget>[
                          // Container(
                          //   decoration: BoxDecoration(
                          //     color: Colors.white,
                          //     borderRadius: BorderRadius.circular(10),
                          //     border: Border.all(
                          //         color: Colors.blue[100]!, width: 1),
                          //   ),
                          //   padding: EdgeInsets.all(16),
                          //   child: Column(
                          //     crossAxisAlignment: CrossAxisAlignment.start,
                          //     children: [
                          //       Row(
                          //         mainAxisAlignment:
                          //             MainAxisAlignment.spaceBetween,
                          //         children: [
                          //           Text('Status: $_selectedStatus'),
                          //         ],
                          //       ),
                          //       SizedBox(height: 16),
                          //       ListTile(
                          //         title: Text('Mengecek Perangkat CCTV'),
                          //         subtitle: Text(
                          //             '${_currentPosition.latitude}, ${_currentPosition.longitude}'),
                          //       ),
                          //     ],
                          //   ),
                          // ),
                          SizedBox(height: 16),
                          Text('Dokumentasi Kegiatan',
                              style: TextStyle(fontWeight: FontWeight.bold)),
                          SizedBox(height: 8),
                          Container(
                            height: 200,
                            decoration: BoxDecoration(
                              color: Colors.grey[300],
                              borderRadius: BorderRadius.circular(10),
                            ),
                            child: Center(
                              child: _image == null
                                  ? Icon(Icons.camera_alt,
                                      size: 50, color: Colors.grey[600])
                                  : Image.file(File(_imagePath!),
                                      fit: BoxFit.cover),
                            ),
                          ),
                          SizedBox(height: 16),
                          ElevatedButton(
                            onPressed: _pickImage,
                            style: ElevatedButton.styleFrom(
                              backgroundColor: Colors.green,
                              foregroundColor: Colors.white,
                              shape: RoundedRectangleBorder(
                                borderRadius: BorderRadius.circular(20),
                              ),
                              minimumSize: Size(double.infinity, 40),
                            ),
                            child: Text(
                              'Upload Gambar Dokumentasi Kegiatan',
                              style: TextStyle(
                                fontSize: 14,
                                fontWeight: FontWeight.bold,
                              ),
                            ),
                          ),
                          SizedBox(height: 16),
                          Text('Deskripsi',
                              style: TextStyle(fontWeight: FontWeight.bold)),
                          SizedBox(height: 8),
                          TextField(
                            controller: _deskripsiController,
                            decoration: InputDecoration(
                              hintText: 'Tambahkan Catatan',
                              border: OutlineInputBorder(),
                            ),
                            maxLines: 3,
                          ),
                          SizedBox(height: 16),
                          Text('Dokumen',
                              style: TextStyle(fontWeight: FontWeight.bold)),
                          SizedBox(height: 8),
                          ElevatedButton(
                            onPressed: _pickDocument,
                            style: ElevatedButton.styleFrom(
                              backgroundColor: Colors.green,
                              foregroundColor: Colors.white,
                              shape: RoundedRectangleBorder(
                                borderRadius: BorderRadius.circular(20),
                              ),
                              minimumSize: Size(double.infinity, 40),
                            ),
                            child: Text(
                              'Upload Dokumen',
                              style: TextStyle(
                                fontSize: 14,
                                fontWeight: FontWeight.bold,
                              ),
                            ),
                          ),
                          if (_documentPath != null)
                            Padding(
                              padding: const EdgeInsets.only(top: 8.0),
                              child:
                                  Text('Dokumen yang dipilih: $_documentPath'),
                            ),
                          SizedBox(height: 16),
                          Text('Lokasi Terkini',
                              style: TextStyle(fontWeight: FontWeight.bold)),
                          SizedBox(height: 8),
                          Text(_currentLocation),
                          SizedBox(height: 8),
                          ElevatedButton(
                            onPressed: _getCurrentLocation,
                            style: ElevatedButton.styleFrom(
                              backgroundColor: Colors.green,
                              foregroundColor: Colors.white,
                              shape: RoundedRectangleBorder(
                                borderRadius: BorderRadius.circular(20),
                              ),
                              minimumSize: Size(double.infinity, 40),
                            ),
                            child: Text(
                              'Deteksi Lokasi',
                              style: TextStyle(
                                fontSize: 14,
                                fontWeight: FontWeight.bold,
                              ),
                            ),
                          ),
                          SizedBox(height: 16),
                          Text('Alamat Terkini',
                              style: TextStyle(fontWeight: FontWeight.bold)),
                          SizedBox(height: 8),
                          Text(_address),
                          SizedBox(height: 24),
                          Container(
                            width: double.infinity,
                            height: 40,
                            child: ElevatedButton(
                              onPressed: () async {
                                try {
                                  await _reportController.createReport(
                                    taskId: widget.taskId,
                                    description:
                                        _deskripsiController.text.trim(),
                                    longitude: _currentPosition.longitude,
                                    latitude: _currentPosition.latitude,
                                    uploadedFilePath1: _imagePath,
                                    uploadedFilePath2: _documentPath,
                                  );

                                  // Tambahkan logging untuk debugging
                                  print('Task ID: ${widget.taskId}');
                                  print(
                                      'Deskripsi: ${_deskripsiController.text.trim()}');
                                  print(
                                      'Longitude: ${_currentPosition.longitude}');
                                  print(
                                      'Latitude: ${_currentPosition.latitude}');
                                  print('Gambar Path: ${_imagePath}');
                                  print('Dokumen Path: $_documentPath');

                                  // Tampilkan pesan sukses
                                  ScaffoldMessenger.of(context).showSnackBar(
                                    SnackBar(
                                        content:
                                            Text('Laporan berhasil disimpan')),
                                  );

                                  // Kembali ke layar sebelumnya
                                  Navigator.pop(context, true);
                                } catch (e) {
                                  // Tangani error
                                  ScaffoldMessenger.of(context).showSnackBar(
                                    SnackBar(
                                        content: Text(
                                            'Gagal menyimpan laporan: $e')),
                                  );
                                }
                              },
                              style: ElevatedButton.styleFrom(
                                backgroundColor: Colors.green,
                                foregroundColor: Colors.white,
                                shape: RoundedRectangleBorder(
                                  borderRadius: BorderRadius.circular(20),
                                ),
                              ),
                              child: Text(
                                _isSaving ? 'Menyimpan...' : 'Simpan Laporan',
                                style: TextStyle(
                                  fontSize: 16,
                                  fontWeight: FontWeight.bold,
                                ),
                              ),
                            ),
                          ),
                          SizedBox(height: 16),
                        ],
                      ),
                    ),
                  ],
                ),
              );
            },
          ),
        ],
      ),
    );
  }
}
