import 'package:Monitoring/pages/kegiatan/pdflaporankegiatan.dart';
import 'package:flutter/material.dart';
import 'package:image_picker/image_picker.dart';
import 'package:flutter_map/flutter_map.dart';
import 'package:latlong2/latlong.dart';
import 'package:Monitoring/controllers/report_controller.dart';
import 'package:Monitoring/models/report_model.dart';
import 'package:Monitoring/widget/refreshable_gadget.dart';
import 'package:Monitoring/constants/constants.dart';
import 'package:get/get.dart';
import 'package:get_storage/get_storage.dart';
import 'package:http/http.dart' as http;
import 'dart:typed_data'; // Import for Uint8List
import 'dart:io';
import 'package:open_file/open_file.dart';

import 'package:dio/dio.dart';
import 'package:path_provider/path_provider.dart';

// void main() {
//   runApp(MyApp());
// }

// class MyApp extends StatelessWidget {
//   @override
//   Widget build(BuildContext context) {
//     return MaterialApp(
//       title: 'Laporan Kegiatan',
//       theme: ThemeData(
//         primarySwatch: Colors.blue,
//         visualDensity: VisualDensity.adaptivePlatformDensity,
//       ),
//       home: MelihatLaporanKegiatan(),
//     );
//   }
// }

class MelihatLaporanKegiatan extends StatefulWidget {
  const MelihatLaporanKegiatan({
    super.key,
    required this.taskId,
  });

  final String taskId;

  @override
  _MelihatLaporanKegiatanState createState() => _MelihatLaporanKegiatanState();
}

class _MelihatLaporanKegiatanState extends State<MelihatLaporanKegiatan> {
  final ImagePicker _picker = ImagePicker();
  XFile? _image;
  String? _documentPath;
  String _selectedStatus = 'Diserahkan';
  final List<String> _statusOptions = [
    'Diterima',
    'Diserahkan',
    'Dikembalikan'
  ];
  ReportController _reportController = ReportController();
  final MapController _mapController = MapController();
  final TextEditingController _catatanController = TextEditingController();

  LatLng _markerPosition = LatLng(-6.200000, 106.816666);

  Future<Uint8List?> fetchImage(String imageUrl) async {
    final box = GetStorage();
    final token = box.read('token'); // Retrieve the token

    final response = await http.get(
      Uri.parse(imageUrl),
      headers: {
        'Authorization': 'Bearer $token', // Include the token in the headers
      },
    );

    if (response.statusCode == 200) {
      return response.bodyBytes; // Return the image bytes
    } else {
      // Handle error
      print('Failed to load image: ${response.statusCode}');
      return null;
    }
  }

  Future<void> _downloadFile(String url, BuildContext context) async {
    try {
      final box = GetStorage();
      final response = await Dio().get(url,
          options: Options(
            responseType: ResponseType.bytes,
            headers: {
              'Authorization': 'Bearer ${box.read('token')}',
            },
          ));
      final bytes = response.data;

      final dir = await getTemporaryDirectory();
      final file = File('${dir.path}/${url.split('/').last}');

      await file.writeAsBytes(bytes);
      // ScaffoldMessenger.of(context).showSnackBar(
      //   SnackBar(content: Text('Document downloaded to ${file.path}')),
      // );

      // Open the downloaded file
      OpenFile.open(file.path);
    } catch (e) {
      ScaffoldMessenger.of(context).showSnackBar(
        SnackBar(content: Text('Error downloading document: $e')),
      );
    }
  }

  void _simpanCatatan() async {
    try {
      await _reportController.updateReportComment(
          _reportController.report.value.first.id!,
          _selectedStatus,
          _catatanController.text);

      ScaffoldMessenger.of(context).showSnackBar(
        const SnackBar(content: Text('Catatan berhasil disimpan')),
      );

      await _reportController.getReport(widget.taskId);
      _catatanController.clear();
    } catch (e) {
      ScaffoldMessenger.of(context).showSnackBar(
        SnackBar(content: Text('Gagal menyimpan catatan: $e')),
      );
    }
  }



  final List<Map<String, dynamic>> _databaseCoordinates = [
    {'latitude': -6.175110, 'longitude': 106.865036},
    {'latitude': -7.797068, 'longitude': 110.370529},
  ];

  final box = GetStorage();

  bool get _isAdmin {
    return box.read('guard') == 'admin';
  }

  @override
  void initState() {
    super.initState();
    print('taskID');
    print(widget.taskId);
    _reportController.getReport2(widget.taskId).then((_) {
      if (mounted) {
        setState(() {
          _markerPosition.longitude =
              _reportController.report.value.first.longitude!;
          _markerPosition.latitude =
              _reportController.report.value.first.latitude!;
          _mapController.move(_markerPosition, 13.0);
          _selectedStatus = _reportController.report.value.first.status!;
          _catatanController.text =
              _reportController.report.value.first.comment!;
        });
      }
    });

    // _getCoordinatesFromDatabase();
  }

  // Future<void> _getCoordinatesFromDatabase() async {
  //   await Future.delayed(const Duration(seconds: 2));
  //   double latitude = _databaseCoordinates[0]['latitude'];
  //   double longitude = _databaseCoordinates[0]['longitude'];

  //   setState(() {
  //     _markerPosition = LatLng(latitude, longitude);
  //   });
  // }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        backgroundColor: Colors.blue[100],
        title: const Text(
          'Lihat Kegiatan',
          style: TextStyle(color: Colors.black),
        ),
        centerTitle: true,
      ),
      body: Stack(
        children: <Widget>[
          FlutterMap(
            mapController: _mapController,
            options: MapOptions(
              center: _markerPosition,
              zoom: 13.0,
            ),
            children: [
              TileLayer(
                urlTemplate:
                    "https://{s}.tile.openstreetmap.org/{z}/{x}/{y}.png",
                subdomains: ['a', 'b', 'c'],
              ),
              MarkerLayer(
                markers: [
                  Marker(
                    point: _markerPosition,
                    builder: (ctx) => const Icon(
                      Icons.location_pin,
                      color: Colors.red,
                      size: 40,
                    ),
                    width: 80.0,
                    height: 80.0,
                  ),
                ],
              ),
            ],
          ),
          DraggableScrollableSheet(
            initialChildSize: 0.3,
            minChildSize: 0.1,
            maxChildSize: 0.9,
            builder: (BuildContext context, ScrollController scrollController) {
              return Container(
                decoration: BoxDecoration(
                  color: Colors.white,
                  borderRadius: const BorderRadius.only(
                    topLeft: Radius.circular(20),
                    topRight: Radius.circular(20),
                  ),
                  boxShadow: [
                    BoxShadow(
                      color: Colors.black.withOpacity(0.1),
                      blurRadius: 10,
                      spreadRadius: 5,
                    ),
                  ],
                ),
                child: Column(
                  children: [
                    Container(
                      width: 40,
                      height: 5,
                      margin: const EdgeInsets.symmetric(vertical: 8),
                      decoration: BoxDecoration(
                        color: Colors.grey[300],
                        borderRadius: BorderRadius.circular(2.5),
                      ),
                    ),
                    Expanded(
                      child: ListView(
                        controller: scrollController,
                        padding: const EdgeInsets.all(16),
                        children: <Widget>[
                          Container(
                            decoration: BoxDecoration(
                              color: Colors.blue[100],
                              borderRadius: BorderRadius.circular(10),
                              border: Border.all(color: Colors.blue, width: 1),
                            ),
                            padding: const EdgeInsets.all(16),
                            child: Column(
                              crossAxisAlignment: CrossAxisAlignment.start,
                              children: [
                                RichText(
                                  text: TextSpan(
                                    style: const TextStyle(
                                        color: Colors.black,
                                        fontSize: 15), // Ukuran font default
                                    children: [
                                      const TextSpan(
                                        text: 'Status: ',
                                        style: TextStyle(
                                            fontWeight: FontWeight.bold,
                                            fontSize: 15), // Bold + font 15
                                      ),
                                      TextSpan(
                                        text: _selectedStatus,
                                        style: const TextStyle(
                                            fontWeight: FontWeight.bold,
                                            fontSize: 15),
                                      ),
                                    ],
                                  ),
                                ),
                                const SizedBox(height: 16),
                                RichText(
                                  text: TextSpan(
                                    style: const TextStyle(
                                        color: Colors.black, fontSize: 15),
                                    children: [
                                      const TextSpan(
                                        text: 'Catatan: ',
                                        style: TextStyle(
                                            fontWeight: FontWeight.normal,
                                            fontSize: 15), // Bold + font 15
                                      ),
                                      TextSpan(
                                        text: _catatanController.text ?? '-',
                                        style: const TextStyle(
                                            fontWeight: FontWeight.normal,
                                            fontSize: 15),
                                      ),
                                    ],
                                  ),
                                ),
                              ],
                            ),
                          ),

                          const SizedBox(height: 16),
                          const Text('Dokumentasi Kegiatan',
                              style: TextStyle(fontWeight: FontWeight.bold)),
                          const SizedBox(height: 8),
                          RefreshableWidget(
                            onRefresh: () async {
                              await _reportController.getReport2(widget.taskId);
                            },
                            isLoading: _reportController.isLoading,
                            child: Obx(() {
                              if (_reportController.report.value.isEmpty) {
                                return Text(
                                  'Loading Gambar',
                                  style: TextStyle(
                                      fontSize: 16, color: Colors.grey),
                                );
                              }

                              // Fetch the image data
                              return FutureBuilder<Uint8List?>(
                                future: fetchImage(_reportController
                                    .report.value.first.photo!),
                                builder: (context, snapshot) {
                                  if (snapshot.connectionState ==
                                      ConnectionState.waiting) {
                                    return CircularProgressIndicator(); // Show loading indicator
                                  } else if (snapshot.hasError) {
                                    return Text(
                                        'Error loading image'); // Handle error
                                  } else if (snapshot.hasData &&
                                      snapshot.data != null) {
                                    return Container(
                                      width: double
                                          .infinity, // Make the container take full width
                                      child: Image.memory(
                                        snapshot.data!, // Use the image bytes
                                        fit: BoxFit
                                            .cover, // Adjust the image to cover the container
                                      ),
                                    );
                                  } else {
                                    return Text(
                                        'No image available'); // Handle case where no image is available
                                  }
                                },
                              );
                            }),
                          ),
                          // SingleChildScrollView for images

                          const SizedBox(height: 16),
                          const Text('Notes',
                              style: TextStyle(fontWeight: FontWeight.bold)),
                          const SizedBox(height: 8),
                          Container(
                            padding: const EdgeInsets.all(16),
                            decoration: BoxDecoration(
                              color: Colors.grey[300],
                              borderRadius: BorderRadius.circular(10),
                            ),
                            child: RefreshableWidget(
                                onRefresh: () async {
                                  await _reportController
                                      .getReport2(widget.taskId);
                                },
                                isLoading: _reportController.isLoading,
                                child: Obx(() {
                                  if (_reportController.report.value.isEmpty) {
                                    return Text(
                                      'Tidak ada laporan tersedia.',
                                      style: TextStyle(
                                          fontSize: 16, color: Colors.grey),
                                    );
                                  }

                                  return Text(
                                    _reportController
                                        .report.value.first.description!,
                                    style: TextStyle(fontSize: 16),
                                  );
                                })),
                          ),
                          const SizedBox(height: 16),
                          const Text('File Dokumentasi',
                              style: TextStyle(fontWeight: FontWeight.bold)),
                          const SizedBox(height: 8),
                          Container(
                            padding: const EdgeInsets.all(8),
                            decoration: BoxDecoration(
                              // color: Colors.grey[300],
                              borderRadius: BorderRadius.circular(10),
                            ),
                            child: Row(
                              mainAxisAlignment: MainAxisAlignment.spaceBetween,
                              children: [
                                ElevatedButton.icon(
                                  style: ElevatedButton.styleFrom(
                                    backgroundColor:
                                        Colors.blue[100], // Warna biru muda
                                    foregroundColor:
                                        Colors.black, // Warna ikon & teks
                                    padding: const EdgeInsets.symmetric(
                                        horizontal: 50, vertical: 10),
                                    shape: RoundedRectangleBorder(
                                      borderRadius: BorderRadius.circular(
                                          8), // Sudut membulat
                                    ),
                                  ),
                                  icon: const Icon(Icons
                                      .document_scanner), // Ikon edit dokumen
                                  label:
                                      const Text("Lihat File"), // Label tombol
                                  onPressed: () async {
                                    await _downloadFile(
                                      _reportController.reportFile.value.first,
                                      context,
                                    );
                                  },
                                ),
                              ],
                            ),
                          ),
                          if (_isAdmin) const SizedBox(height: 24),
                          if (_isAdmin)
                            Container(
                              height: 2, // Ketebalan garis
                              color: Colors.black, // Warna garis
                            ),
                          const SizedBox(height: 24),
                          if (_isAdmin)
                            Container(
                              decoration: BoxDecoration(
                                color: Colors.grey[300],
                                borderRadius: BorderRadius.circular(10),
                                border:
                                    Border.all(color: Colors.blue, width: 1),
                              ),
                              padding: const EdgeInsets.all(16),
                              child: Column(
                                crossAxisAlignment: CrossAxisAlignment.start,
                                children: [
                                  Text('Status: $_selectedStatus'),
                                  if (_isAdmin)
                                    DropdownButton<String>(
                                      value: _selectedStatus,
                                      onChanged: (String? newValue) {
                                        setState(() {
                                          _selectedStatus = newValue!;
                                        });
                                      },
                                      items: _statusOptions
                                          .map<DropdownMenuItem<String>>(
                                              (String value) {
                                        return DropdownMenuItem<String>(
                                          value: value,
                                          child: Text(value),
                                        );
                                      }).toList(),
                                    )
                                  else
                                    Text(_selectedStatus),
                                  ListTile(
                                    subtitle: Text(
                                        '${_markerPosition.latitude}, ${_markerPosition.longitude}'),
                                  ),
                                ],
                              ),
                            ),
                          const SizedBox(height: 16),
                          if (_isAdmin) ...[
                            const Text('Tambah Catatan',
                                style: TextStyle(fontWeight: FontWeight.bold)),
                            const SizedBox(height: 8),
                            Container(
                              child: Column(
                                crossAxisAlignment: CrossAxisAlignment.stretch,
                                children: [
                                  TextField(
                                    controller: _catatanController,
                                    maxLines: 3,
                                    decoration: const InputDecoration(
                                      hintText: 'Tulis catatan tambahan...',
                                      border: OutlineInputBorder(),
                                    ),
                                  ),
                                  const SizedBox(height: 16),
                                ],
                              ),
                            ),
                          ],
                          if (_isAdmin)
                            ElevatedButton(
                              onPressed: _simpanCatatan,
                              style: ElevatedButton.styleFrom(
                                backgroundColor: Colors.blue,
                                shape: RoundedRectangleBorder(
                                  borderRadius: BorderRadius.circular(10),
                                ),
                              ),
                              child: const Text(
                                'Simpan',
                                style: TextStyle(color: Colors.white),
                              ),
                            ),
                          const SizedBox(height: 16),
                        ],
                      ),
                    ),
                  ],
                ),
              );
            },
          ),
        ],
      ),
    );
  }
}
